Dependencies
==============

Langformers is built with ❤️ around the following widely adopted python libraries.

- tokenizers
- transformers
- datasets
- torch
- accelerate
- safetensors
- scikit-learn
- ollama
- uvicorn
- fastapi
- pandas
- numpy
- tqdm
- chromadb
- pinecone
- faiss-cpu
- colorama
- tensorboard
- requests
- bitsandbytes